@@ -15,7 +15,7 @@ def gridfs_view(request):
 
     try:
         conn = pymongo.Connection(host, int(port))
-        LOG.info('Connected to mongodb://%s:%s/%s'  % (host, port, database))
+        LOG.debug('Connected to mongodb://%s:%s/%s'  % (host, port, database))
         filename = request.params.get('filename')
         collection = request.params.get('collection', 'files')
 
@@ -25,7 +25,13 @@ def gridfs_view(request):
         if not fs.exists(filename):
             return Response(status=404)
 
-        fp = fs.get(filename)
-        return Response(app_iter=fs.get(filename))
+        grid_file = fs.get(filename)
+        ct = grid_file.content_type
+        headers = [('content-length', grid_file.length),
+                  ]
+        if ct:
+            headers.append(('content-type', grid_file.content_type))
+        return Response(app_iter=grid_file,
+                        headers=headers)
     finally:
         conn.disconnect()
